@@ -23,7 +23,7 @@ syncLocalLibList <- function(lib=reposToolsLibPaths(), quiet=TRUE) {
         if (file.access(lib[i],mode=2) != 0) {
             if (!quiet) {
                 cat("\n\t")
-                note(paste("reposTools can not access ",lib[i],".\n\t",
+                rt_note(paste("reposTools can not access ",lib[i],".\n\t",
                            "This will not affect your R session unless ",
                            "you wish \n\tto install/update/remove packages ",
                            "from this directory\n",sep=""))
@@ -282,7 +282,7 @@ is.installed <- function(pkg, vers=NULL,
         }
         else {
             if (verbose == TRUE)
-                note(paste("No locliblisting in R library",lib))
+                rt_note(paste("No locliblisting in R library",lib))
         }
     }
     return(FALSE)
@@ -313,7 +313,7 @@ getPkgVers <- function(pkg, libs=reposToolsLibPaths(), verbose=TRUE) {
         }
         else {
             if (verbose == TRUE)
-                note(paste("No locliblisting in R library",lib))
+                rt_note(paste("No locliblisting in R library",lib))
         }
     }
     return(vers)
@@ -477,6 +477,12 @@ solveForwardDepends <- function(pkgInfo, repEntry, lib, depLevel,
                                 versForce=TRUE, method="auto",
                                 getNewest=getNewest,
                                 develOK=FALSE, curRepList=NULL) {
+    if (develOK)
+      warning("The develOK option is deprecated and will be ignored.\n",
+              "If you would like to install development versions of\n",
+              "Bioconductor packages, please install a development\n",
+              "version of R.")
+
     pkg <- pkgName(pkgInfo)
     vers <- pkgVersion(pkgInfo)
     curPkgInfo <- new("pkgInfo", pkgName=pkg, pkgVersion=vers)
@@ -549,7 +555,7 @@ solveForwardDepends <- function(pkgInfo, repEntry, lib, depLevel,
                                               searchOptions=searchOptions,
                                               getAllDeps=getAllDeps,
                                               method=method,
-                                              develOK=develOK)
+                                              develOK=FALSE)
                     updPkgs <- updatedPkgs(inOut)
                     ## Now check again to see if we have the package
                     if (length(updPkgs) > 0) {
@@ -560,7 +566,7 @@ solveForwardDepends <- function(pkgInfo, repEntry, lib, depLevel,
                 }
                 if (brk == TRUE) {
                     out <- c(out,errMsg)
-                    note(paste("Package",depPkg,
+                    rt_note(paste("Package",depPkg,
                                "not found in any known repository."))
                 }
             }
@@ -611,7 +617,7 @@ repositories <- function(recurse=TRUE, method="auto") {
 remove.packages2 <- function(pkgs, lib, force=FALSE) {
     if (missing(lib) || is.null(lib)) {
         lib <- reposToolsLibPaths()[1]
-        note(paste("argument `lib' is missing: using", lib))
+        rt_note(paste("argument `lib' is missing: using", lib))
     }
     if (load.locLib(lib) == FALSE) {
         return(FALSE)
@@ -619,7 +625,7 @@ remove.packages2 <- function(pkgs, lib, force=FALSE) {
 
     for (pkg in pkgs) {
         if (!is.installed(pkg)) {
-            note(paste("Package",pkg,"is not installed"))
+            rt_note(paste("Package",pkg,"is not installed"))
             next
         }
         vers <- getPkgVers(pkg, lib)[[1]]
@@ -663,6 +669,11 @@ install.packages2 <- function(pkgs=NULL, repEntry=NULL, lib, versions,
                               recurse=TRUE, searchOptions=FALSE, getNewest=TRUE,
                               force=FALSE, versForce=TRUE, getAllDeps=FALSE,
                               fileSelect=baseFileSelect, develOK=FALSE) {
+    if (develOK)
+      warning("The develOK option is deprecated and will be ignored.\n",
+              "If you would like to install development versions of\n",
+              "Bioconductor packages, please install a development\n",
+              "version of R.")
 
     if (missing(lib))
         lib <- reposToolsLibPaths()[1]
@@ -736,7 +747,7 @@ install.packages2 <- function(pkgs=NULL, repEntry=NULL, lib, versions,
                                                   checkRep[[curRepEntry]]))
             }
             if (length(pkgs) == 0)
-                note(paste("Theme '", theme[curTheme],
+                rt_note(paste("Theme '", theme[curTheme],
                            "' was not found.", sep=""))
         }
         if (length(pkgs) == 0)
@@ -751,7 +762,7 @@ install.packages2 <- function(pkgs=NULL, repEntry=NULL, lib, versions,
         if (is.null(type))
             stop("Can not determine default download type")
         else
-            note(paste("Using download type:", type))
+            rt_note(paste("Using download type:", type))
     }
 
     ## Make sure that the requested lib directory is synch'ed
@@ -763,7 +774,7 @@ install.packages2 <- function(pkgs=NULL, repEntry=NULL, lib, versions,
 
         ## Retrieve the pkgList object for this download
         pkgList <- buildPkgListing(repList, pkgs, type,
-                                   develOK=develOK,method=method)
+                                   develOK=FALSE,method=method)
 
         if (!is.null(versions)) {
             ## If versions were specified then we are downloading
@@ -783,7 +794,7 @@ install.packages2 <- function(pkgs=NULL, repEntry=NULL, lib, versions,
                                                 searchOptions=searchOptions,
                                                 getAllDeps=getAllDeps,
                                                 method=method,
-                                                develOK=develOK,
+                                                develOK=FALSE,
                                                 curRepList=repList)
         }
     }
@@ -828,7 +839,7 @@ download.packages2 <- function(pkgs, repEntry, destDir, versions,
     }
 
     if (missing(destDir)) {
-        note("destDir parameter missing, using current directory")
+        rt_note("destDir parameter missing, using current directory")
         destDir <- getwd()
     }
     else
@@ -840,11 +851,11 @@ download.packages2 <- function(pkgs, repEntry, destDir, versions,
         if (is.null(type))
             stop("Can not determine default download type")
         else
-            note(paste("Using download type:", type))
+            rt_note(paste("Using download type:", type))
     }
 
     if (missing(pkgs)) {
-        note("pkgs parameter missing, downloading all packages in repository")
+        rt_note("pkgs parameter missing, downloading all packages in repository")
         pkgs <- repPkgs(repEntry)
     }
 
@@ -899,10 +910,16 @@ update.packages2 <- function(pkgs=NULL, repEntry=NULL, theme=NULL,
                              searchOptions=FALSE, force=FALSE, versForce=TRUE,
                              getAllDeps=FALSE, develOK=FALSE) {
 
+    if (develOK)
+      warning("The develOK option is deprecated and will be ignored.\n",
+              "If you would like to install development versions of\n",
+              "Bioconductor packages, please install a development\n",
+              "version of R.")
+
     ## First get the list of libraries that we are updating
     if (missing(libs) || is.null(libs)) {
         libs <- reposToolsLibPaths()
-        note(paste("argument `lib' is missing: using", libs))
+        rt_note(paste("argument `lib' is missing: using", libs))
     }
 
     ## Make sure that these libraries are synch'd
@@ -943,7 +960,7 @@ update.packages2 <- function(pkgs=NULL, repEntry=NULL, theme=NULL,
         if (is.null(type))
             stop("Can not determine default download type")
         else
-            note(paste("Using download type:", type))
+            rt_note(paste("Using download type:", type))
     }
 
     out <- vector(mode="list", length=length(libs))
@@ -968,7 +985,7 @@ update.packages2 <- function(pkgs=NULL, repEntry=NULL, theme=NULL,
         if (length(pkgs) != 0) {
 
             pkgList <- buildPkgListing(repList, pkgs, type,
-                                       develOK=develOK, method=method)
+                                       develOK=FALSE, method=method)
             Packages <- pkgList(pkgList)
             if (length(Packages) == 0)
                 return(new("pkgStatusList",statusList=list()))
@@ -1019,7 +1036,7 @@ update.packages2 <- function(pkgs=NULL, repEntry=NULL, theme=NULL,
                                       searchOptions=searchOptions,
                                       force=force, versForce=versForce,
                                       getAllDeps=getAllDeps,
-                                      develOK=develOK)
+                                      develOK=FALSE)
             }
             out[[lib]] <- pStatList
         }
@@ -1085,6 +1102,12 @@ baseFileSelect <- function(pkgList, lib, type, getNewest=TRUE,
                            versForce=TRUE, force=FALSE, searchOptions=FALSE,
                            getAllDeps=TRUE, method="auto",
                            develOK=FALSE, curRepList=NULL) {
+    if (develOK)
+      warning("The develOK option is deprecated and will be ignored.\n",
+              "If you would like to install development versions of\n",
+              "Bioconductor packages, please install a development\n",
+              "version of R.")
+
     pkgStats <- new("pkgStatusList",statusList=list())
     Packages <- pkgList(pkgList)
     if (length(Packages) == 0)
@@ -1147,7 +1170,7 @@ baseFileSelect <- function(pkgList, lib, type, getNewest=TRUE,
                                "site for package ", pkgs[i],":",sep="")
                 index <- menu(choices,title=title)
                 if (index == 0) {
-                    note(paste("Skippping package",pkgs[i]))
+                    rt_note(paste("Skippping package",pkgs[i]))
                     next()
                 }
             }
@@ -1170,7 +1193,7 @@ baseFileSelect <- function(pkgList, lib, type, getNewest=TRUE,
                               searchOptions=searchOptions,
                               getAllDeps=getAllDeps,
                               versForce=versForce,
-                              getNewest=getNewest, develOK=develOK,
+                              getNewest=getNewest, develOK=FALSE,
                               curRepList=curRepList, method=method)
 
         rdPkgs <- get("pkgList",rd)
@@ -1255,7 +1278,7 @@ installPkg <- function(fileName, pkg, vers, type, lib, repEntry,
                 }
                 else {
                     out <- paste(out,", installing anyway.\n")
-                    note(out)
+                    rt_note(out)
                 }
             }
             if (OST != "windows") {
